Exporting 
=========

.. autofunction:: emiproc.exports.netcdf.nc_cf_attributes

.. autofunction:: emiproc.exports.icon.export_icon_oem

.. autofunction:: emiproc.exports.icon.make_icon_time_profiles

.. autofunction:: emiproc.exports.icon.make_icon_vertical_profiles

.. autoenum:: emiproc.exports.icon.TemporalProfilesTypes
    
.. autofunction:: emiproc.exports.rasters.export_raster_netcdf

.. autofunction:: emiproc.exports.profiles.export_inventory_profiles

.. autofunction:: emiproc.exports.utils.get_temporally_scaled_array

.. autofunction:: emiproc.exports.wrf.export_wrf_hourly_emissions


Gral
----
.. automodule:: emiproc.exports.gral
    :members: